@@ -607,6 +607,7 @@ fb_xnnpack.XNodeUnion = class {
             case 42: return fb_xnnpack.XNNGelu.decode(reader, position);
             case 43: return fb_xnnpack.XNNTanh.decode(reader, position);
             case 44: return fb_xnnpack.XNNExp.decode(reader, position);
+            case 45: return fb_xnnpack.XNNSin.decode(reader, position);
             default: return undefined;
         }
     }
@@ -1220,6 +1221,15 @@ fb_xnnpack.XNNExp = class XNNExp {
     }
 };
 
+fb_xnnpack.XNNSin = class XNNSin {
+
+    static decode(reader, position) {
+        const $ = new fb_xnnpack.XNNSin();
+        fb_xnnpack._XNNNode1x1.decode(reader, position, $);
+        return $;
+    }
+};
+
 vkgraph.OperatorCall = class OperatorCall {
 
     static decode(reader, position) {
